package com.sun.org.apache.xml.internal.security.keys.content;

import com.sun.org.apache.xml.internal.security.signature.XMLSignatureException;
import com.sun.org.apache.xml.internal.security.utils.XMLUtils;
import org.w3c.dom.Attr;
import com.sun.org.apache.xml.internal.security.transforms.Transforms;
import org.w3c.dom.Document;
import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;
import org.w3c.dom.Element;
import com.sun.org.apache.xml.internal.security.utils.SignatureElementProxy;

public class RetrievalMethod extends SignatureElementProxy implements KeyInfoContent
{
    public static final String TYPE_DSA = "http://www.w3.org/2000/09/xmldsig#DSAKeyValue";
    public static final String TYPE_RSA = "http://www.w3.org/2000/09/xmldsig#RSAKeyValue";
    public static final String TYPE_PGP = "http://www.w3.org/2000/09/xmldsig#PGPData";
    public static final String TYPE_SPKI = "http://www.w3.org/2000/09/xmldsig#SPKIData";
    public static final String TYPE_MGMT = "http://www.w3.org/2000/09/xmldsig#MgmtData";
    public static final String TYPE_X509 = "http://www.w3.org/2000/09/xmldsig#X509Data";
    public static final String TYPE_RAWX509 = "http://www.w3.org/2000/09/xmldsig#rawX509Certificate";
    
    public RetrievalMethod(Element element, String baseURI) throws XMLSecurityException {
        super(element, baseURI);
    }
    
    public RetrievalMethod(Document doc, String value, Transforms toAppend, String value2) {
        super(doc);
        this.setLocalAttribute("URI", value);
        if (value2 != null) {
            this.setLocalAttribute("Type", value2);
        }
        if (toAppend != null) {
            this.appendSelf(toAppend);
            this.addReturnToSelf();
        }
    }
    
    public Attr getURIAttr() {
        return this.getElement().getAttributeNodeNS(null, "URI");
    }
    
    public String getURI() {
        return this.getLocalAttribute("URI");
    }
    
    public String getType() {
        return this.getLocalAttribute("Type");
    }
    
    public Transforms getTransforms() throws XMLSecurityException {
        try {
            Element selectDsNode = XMLUtils.selectDsNode(this.getFirstChild(), "Transforms", 0);
            if (selectDsNode != null) {
                return new Transforms(selectDsNode, this.baseURI);
            }
            return null;
        }
        catch (XMLSignatureException originalException) {
            throw new XMLSecurityException(originalException);
        }
    }
    
    @Override
    public String getBaseLocalName() {
        return "RetrievalMethod";
    }
}
